package com.ytpm.feign;

import com.ytpm.app.model.YtDyzUser;
import com.ytpm.feign.fallback.RiskFeignFallBack;
import com.ytpm.general.Result;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

@FeignClient(name = "risk-manage", fallback = RiskFeignFallBack.class)
public interface RiskFeign {
    @PostMapping("/public/checkRisk")
    Result<?> checkRisk(@RequestBody YtDyzUser ytDyzUser);
    @PostMapping("/public/checkAdRisk")
    Result<?> checkAdRisk(@RequestBody YtDyzUser ytDyzUser);
    @PostMapping("/public/checkAdRisk/766")
    Result<?> checkAdRisk766(@RequestBody YtDyzUser ytDyzUser);
    @GetMapping("/public/addDeblockingRecord")
    void addBlockingRecord(@RequestParam("userId")String userId);
    @PostMapping("/public/checkRegRisk")
    Result<?> checkRegRisk(@RequestBody YtDyzUser ytDyzUser);
    @PostMapping("/public/checkLoginRisk")
    Result<?> checkLoginRisk(YtDyzUser old);
    @PostMapping("/public/checkVisitorLogin")
    Result<?> checkVisitorLogin(YtDyzUser old);
}
